@@ -106,7 +106,7 @@ namespace Oxygen
 
             // reparent
             xcb_reparent_window( connection, winId(), current, 0, 0 );
-            setWindowTitle( "Oxygen::SizeGrip" );
+            setWindowTitle( QStringLiteral("Oxygen::SizeGrip") );
 
         } else {
 
@@ -211,7 +211,7 @@ namespace Oxygen
         */
         QPoint rootPosition( position );
         xcb_get_geometry_cookie_t cookie( xcb_get_geometry( connection, winId() ) );
-        ScopedPointer<xcb_get_geometry_reply_t> reply( xcb_get_geometry_reply( connection, cookie, 0x0 ) );
+        ScopedPointer<xcb_get_geometry_reply_t> reply( xcb_get_geometry_reply( connection, cookie, nullptr ) );
         if( reply )
         {
 
@@ -221,7 +221,7 @@ namespace Oxygen
                 -reply.data()->border_width,
                 -reply.data()->border_width ) );
 
-            ScopedPointer< xcb_translate_coordinates_reply_t> coordReply( xcb_translate_coordinates_reply( connection, coordCookie, 0x0 ) );
+            ScopedPointer< xcb_translate_coordinates_reply_t> coordReply( xcb_translate_coordinates_reply( connection, coordCookie, nullptr ) );
 
             if( coordReply )
             {
@@ -236,9 +236,9 @@ namespace Oxygen
         {
 
             // create atom if not found
-            const QString atomName( "_NET_WM_MOVERESIZE" );
+            const QString atomName = QStringLiteral("_NET_WM_MOVERESIZE");
             xcb_intern_atom_cookie_t cookie( xcb_intern_atom( connection, false, atomName.size(), qPrintable( atomName ) ) );
-            ScopedPointer<xcb_intern_atom_reply_t> reply( xcb_intern_atom_reply( connection, cookie, 0x0 ) );
+            ScopedPointer<xcb_intern_atom_reply_t> reply( xcb_intern_atom_reply( connection, cookie, nullptr ) );
             m_moveResizeAtom = reply ? reply->atom:0;
 
         }
